@@ -13,9 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this program; if not, see <https://www.gnu.org/licenses>
  */
 
 #include <config.h>
@@ -25,7 +23,7 @@
 #include <glib.h>
 
 #ifdef HAVE_GSSAPI
-#include <gssapi.h>
+#include <gssapi/gssapi.h>
 #endif
 
 #include "lm-sock.h"
@@ -153,7 +151,7 @@ sasl_gssapi_get_creds (LmSASL *sasl)
     guint32         major_status;
     guint32         minor_status;
 
-    token.value	= g_strdup_printf ("xmpp@%s", sasl->server);
+    token.value        = g_strdup_printf ("xmpp@%s", sasl->server);
     token.length = strlen ((char *)token.value);
 
     if (token.value == NULL) {
